summaryrefslogtreecommitdiff
path: root/ceilometer/compute/notifications/__init__.py
diff options
context:
space:
mode:
Diffstat (limited to 'ceilometer/compute/notifications/__init__.py')
-rw-r--r--ceilometer/compute/notifications/__init__.py14
1 files changed, 6 insertions, 8 deletions
diff --git a/ceilometer/compute/notifications/__init__.py b/ceilometer/compute/notifications/__init__.py
index e3c11910..6f9b6a08 100644
--- a/ceilometer/compute/notifications/__init__.py
+++ b/ceilometer/compute/notifications/__init__.py
@@ -17,6 +17,7 @@
# under the License.
from oslo.config import cfg
+import oslo.messaging
from ceilometer import plugin
@@ -33,13 +34,10 @@ cfg.CONF.register_opts(OPTS)
class ComputeNotificationBase(plugin.NotificationBase):
@staticmethod
- def get_exchange_topics(conf):
- """Return a sequence of ExchangeTopics defining the exchange and
+ def get_targets(conf):
+ """Return a sequence of oslo.messaging.Target defining the exchange and
topics to be connected for this plugin.
"""
- return [
- plugin.ExchangeTopics(
- exchange=conf.nova_control_exchange,
- topics=set(topic + ".info"
- for topic in conf.notification_topics)),
- ]
+ return [oslo.messaging.Target(topic=topic,
+ exchange=conf.nova_control_exchange)
+ for topic in conf.notification_topics]